import os
import sys
if sys.version < (2, 6):
    from distutils.command import register

    def isstr((k, v)):
        return isinstance(v, basestring)

    def patch(func):
        def post_to_server(self, data, auth=None):
            for key, value in filter(isstr, data.items()):
                data[key] = value.decode('utf8')
            return func(self, data, auth)
        return post_to_server

    register.register.post_to_server = patch(register.register.post_to_server)

from setuptools import setup
import bloggerfs

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()


setup(name='bloggerfs',
      version=bloggerfs.__version__,
      author='Marco Giusti',
      author_email='marco.giusti@gmail.com',
      url='http://bitbucket.org/gm/bloggerfs',
      description='Blogger filesystem using FUSE',
      long_description=read('README.txt'),
      license='LGPL',
      keywords='fuse blogger filesystem',
      platforms=['posix'],
      packages=['bloggerfs'],
      install_requires=['zope.interface', 'gdata', 'fuse-python'],
      tests_require=['mock', 'unittest2'],
      test_suite='bloggerfs.tests.all_tests.main',
      entry_points = {
          'console_scripts': [
              'bloggerfs = bloggerfs.bloggerfs:main'
          ],
      },
      classifiers=[
          'Development Status :: 4 - Beta',
          'Environment :: Console',
          'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
          'Operating System :: POSIX',
          'Topic :: System :: Filesystems',
      ]
     )

